OC.L10N.register(
    "settings",
    {
    "Private" : "Закритий",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Відображається лише людям, зіставленим за допомогою інтеграції номера телефону через Talk на мобільному пристрої",
    "Local" : "Локально",
    "Only visible to people on this instance and guests" : "Відображається лише для людей у ​​цьому екземплярі та гостей",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Синхронізовувати лише з серверами, яким довіряємо",
    "Published" : "Опубліковано",
    "Synchronize to trusted servers and the global and public address book" : "Синхронізація з надійними серверами та глобальною та загальнодоступною адресною книгою",
    "Verify" : "Перевірити",
    "Verifying …" : "Перевірка ...",
    "Unable to change password" : "Неможливо змінити пароль",
    "Very weak password" : "Дуже слабкий пароль",
    "Weak password" : "Слабкий пароль",
    "So-so password" : "Такий собі пароль",
    "Good password" : "Добрий пароль",
    "Strong password" : "Надійний пароль",
    "Groups" : "Групи",
    "Group list is empty" : "Список груп порожній",
    "Unable to retrieve the group list" : "Неможливо отримати список груп",
    "{actor} added you to group {group}" : "{actor} додав вас до групи {group}",
    "You added {user} to group {group}" : "Ви додали {user} до групи {group}",
    "{actor} added {user} to group {group}" : "{actor} додав {user} до групи {group}",
    "An administrator added you to group {group}" : "Адміністратор додав вас до групи {group}",
    "An administrator added {user} to group {group}" : "Адміністратор додав {user} до групи {group}",
    "{actor} removed you from group {group}" : "{actor} вилучив вас із групи {group}",
    "You removed {user} from group {group}" : "Ви вилучили {user} з групи {group}",
    "{actor} removed {user} from group {group}" : "{actor} вилучив {user} з групи {group}",
    "An administrator removed you from group {group}" : "Адміністратор вилучив вас з групи {group}",
    "An administrator removed {user} from group {group}" : "Адміністратор вилучив {user} з групи {group}",
    "Your <strong>group memberships</strong> were modified" : "Параметри вашої <strong>участі в групі</strong> оновлено",
    "{actor} changed your password" : "{actor} змінив ваш пароль",
    "You changed your password" : "Ви змінили пароль",
    "Your password was reset by an administrator" : "Ваш пароль був скинутий адміністратором",
    "Your password was reset" : "Ваш пароль скинуто",
    "{actor} changed your email address" : "{actor} змінив адресу вашої ел.пошти",
    "You changed your email address" : "Ви змінили ел.адресу",
    "Your email address was changed by an administrator" : "Ваша email адреса змінена адміністратором",
    "You created app password \"{token}\"" : "Ви створили пароль програми \"{token}\"",
    "An administrator created app password \"{token}\"" : "Адміністратор створив пароль програми \"{token}\"",
    "You deleted app password \"{token}\"" : "Ви вилучили пароль застосунку \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Ви перейменували пароль програми \"{token}\" на \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Ви надали доступ до файлової системи паролю програми \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Ви скасували доступ до файлової системи з паролем програми \"{token}\"",
    "Security" : "Безпека",
    "You successfully logged in using two-factor authentication (%1$s)" : "Ви успішно увійшли з використанням двофакторної автентифікації (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Помилка спроби входу в систему з використанням двофакторної автентифікації (%1$s)",
    "Remote wipe was started on %1$s" : "Розпочато віддалене стирання на %1$s",
    "Remote wipe has finished on %1$s" : "Віддалене стирання на %1$s завершено",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ваш <strong>пароль</strong> чи <strong>електронна пошта</strong> були змінені",
    "Could not remove app." : "Не вдалося вилучити застосунок.",
    "Could not update app." : "Не вдалося оновити програму.",
    "Wrong password" : "Неправильний пароль",
    "Unable to change personal password" : "Неможливо змінити особистий пароль",
    "Saved" : "Збережено",
    "No user supplied" : "Користувача не вказано",
    "Unable to change password. Password too long." : "Неможливо змінити пароль. Пароль задовгий.",
    "Authentication error" : "Помилка автентифікації",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Будь ласка, введіть пароль відновлення адміністратора; інакше всі дані користувача будуть втрачені.",
    "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
    "Backend does not support password change, but the user's encryption key was updated." : "Сервер не підтримує зміну пароля, але ключ шифрування користувача було оновлено.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "встановлення та оновлення програм через App Store або Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL використовує застарілу версію %1$s (%2$s). Оновіть свою операційну систему або такі функції, як %3$s не будуть працювати надійно.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Не вдалося визначити, чи TLS-версія cURL застаріла, оскільки сталася помилка під час запиту HTTPS до https://nextcloud.com. Будь ласка, перевірте файл журналу Nextcloud для отримання додаткової інформації.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Модуль PHP OPcache не завантажується. Для кращої продуктивності рекомендується завантажити його у вашу установку PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache вимкнено. Для кращої продуктивності рекомендується застосувати <code>opcache.enable=1</code> до вашої конфігурації PHP.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache налаштовано на видалення коментарів коду. Якщо OPcache увімкнено, для роботи Nextcloud потрібно встановити <code>opcache.save_comments=1</code>.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud не має права використовувати API OPcache. Якщо OPcache увімкнено, настійно рекомендується включити всі каталоги Nextcloud за допомогою <code>opcache.restrict_api</code> або вимкнути цей параметр, щоб вимкнути обмеження OPcache API, щоб запобігти помилкам під час оновлення ядра Nextcloud або програми.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud не має права використовувати API OPcache. Настійно рекомендується включити всі каталоги Nextcloud у <code>opcache.restrict_api</code> або вимкнути цей параметр, щоб вимкнути обмеження OPcache API, щоб запобігти помилкам під час оновлення ядра Nextcloud або програми.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Майже перевищено максимальну кількість ключів OPcache. Щоб переконатися, що всі сценарії можна зберігати в кеші, рекомендується застосувати <code>opcache.max_accelerated_files</code> до вашої конфігурації PHP зі значенням, вищим за <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Буфер OPcache майже заповнений. Щоб переконатися, що всі сценарії можна зберігати в кеші, рекомендується застосувати <code>opcache.memory_consumption</code> до вашої конфігурації PHP зі значенням, вищим за <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Вбудований буфер рядків OPcache майже заповнений. Щоб забезпечити ефективне кешування рядків, що повторюються, рекомендується застосувати <code>opcache.interned_strings_buffer</code> до вашої конфігурації PHP із значенням, вищим за <code>%s</code>.",
    "Invalid SMTP password." : "Недійсний пароль SMTP.",
    "Email setting test" : "Тестування параметрів електронної пошти",
    "Well done, %s!" : "Молодець, %s!",
    "If you received this email, the email configuration seems to be correct." : "Якщо ви отримали цей електронний лист, то налаштування електронної пошти правильні.",
    "Email could not be sent. Check your mail server log" : "Не вдалося надіслати електронну пошту. Перевірте журнал поштового сервера",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Під час надсилання email сталася помилка. Будь ласка перевірте налаштування. (Помилка: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Перш ніж надсилати тестові електронні листи, вам потрібно встановити електронну адресу користувача. Ідіть %s для цього.",
    "Invalid user" : "Неправильний користувач",
    "Invalid mail address" : "Неправильна email адреса",
    "Settings saved" : "Налаштування збережено",
    "Unable to change full name" : "Неможливо змінити повне ім'я",
    "Unable to change email address" : "Неможливо змінити електронну адресу",
    "Unable to set invalid phone number" : "Не вдалося встановити недійсний номер телефону",
    "Unable to set invalid website" : "Не вдалося встановити недійсний веб-сайт",
    "Some account data was invalid" : "Деякі дані облікового запису недійсні",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Щоб підтвердити свій обліковий запис Twitter, опублікуйте наступний твіт у Twitter (переконайтеся, що опубліковано без розривів рядків):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Щоб підтвердити свій веб-сайт, збережіть наведений нижче вміст у корені вебсервера: '.well-known/CloudIdVerificationCode.txt' (переконайтеся, що повний текст розміщено в один рядок):",
    "%1$s changed your password on %2$s." : "%1$s змінив ваш пароль у хмарі %2$s.",
    "Your password on %s was changed." : "Ваш пароль на сервері %s був змінений.",
    "Your password on %s was reset by an administrator." : "Ваш пароль на сервері %s був скинутий адміністратором",
    "Your password on %s was reset." : "Ваш пароль на %s перевстановлено.",
    "Password for %1$s changed on %2$s" : "Пароль %1$s змінений на сервері %2$s",
    "Password changed for %s" : "Пароль змінено для %s",
    "If you did not request this, please contact an administrator." : "Якщо ви цього не просили, зв'яжіться з адміністратором.",
    "Your email address on %s was changed." : "Ваша електронна адреса на сервері %s була змінена.",
    "Your email address on %s was changed by an administrator." : "Ваша електронна адреса на сервері %s була змінена адміністратором.",
    "Email address for %1$s changed on %2$s" : "Електронна адреса %1$s змінена на %2$s",
    "Email address changed for %s" : "Адресу електронної пошти змінено для %s",
    "The new email address is %s" : "Нова адреса електронної пошти: %s",
    "Your %s account was created" : "Ваш обліковий запис %s створено",
    "Welcome aboard" : "Ласкаво просимо на борт",
    "Welcome aboard %s" : "Ласкаво просимо на борт, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Ласкаво просимо до вашого облікового запису, %s, ви можете додавати, захищати та ділитися своїми даними.",
    "Your username is: %s" : "Ваше ім'я користувача: %s",
    "Set your password" : "Встановіть свій пароль",
    "Go to %s" : "Перейти до %s",
    "Install Client" : "Встановити Клієнт",
    "Logged in user must be a subadmin" : "Користувач, який увійшов, має бути одним з адміністраторів",
    "Apps" : "Застосунки",
    "Settings" : "Налаштування",
    "Personal" : "Особисте",
    "Administration" : "Адміністрування",
    "Additional settings" : "Додаткові налаштування",
    "Administration privileges" : "Привілеї адміністратора",
    "Groupware" : "Робочі групи",
    "Overview" : "Огляд",
    "Basic settings" : "Основні налаштування",
    "Sharing" : "Спільний доступ",
    "Availability" : "Доступність",
    "Personal info" : "Особиста інформація",
    "Mobile & desktop" : "Смартфон та ноутбук",
    "Email server" : "Сервер електронної пошти",
    "Security & setup warnings" : "Попередження безпеки та налаштування",
    "Background jobs" : "Фонові завдання",
    "Create" : "Створити",
    "Change" : "Змінити",
    "Delete" : "Вилучити",
    "Reshare" : "Повторно поділитися",
    "Unlimited" : "Необмежено",
    "Verifying" : "Перевірка",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Очікується фонове завдання, яке перевіряє імпортовані користувачем сертифікати SSL. Перевірте пізніше.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Є деякі сертифікати SSL, імпортовані користувачем, які більше не використовуються з Nextcloud 21. Їх можна імпортувати в командному рядку за допомогою команди «occ security:certificates:import». Їхні шляхи всередині каталогу даних показано нижче.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Знайдено недійсні UUID користувачів або груп LDAP. Будь ласка, перегляньте свої параметри «Перевизначити виявлення UUID» у експертній частині конфігурації LDAP і використовуйте «occ ldap:update-uuid», щоб оновити їх.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Старий формат шифрування на стороні сервера ввімкнено. Рекомендуємо вимкнути це.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Використовується версія MariaDB \"%s\". Nextcloud 21 і вище не підтримують цю версію і потребують MariaDB 10.2 або вище.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Використовується версія MySQL \"%s\". Nextcloud 21 і вище не підтримують цю версію і потребують MySQL 8.0 або MariaDB 10.2 або вище.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Використовується версія PostgreSQL \"%s\". Nextcloud 21 і вище не підтримують цю версію і потребують PostgreSQL 9.6 або вище.",
    "Profile information" : "Інформація профілю",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Зображення профілю, повне ім’я, електронна адреса, номер телефону, адреса, веб-сайт, Twitter, організація, роль, заголовок, біографія та чи активовано ваш профіль",
    "Nextcloud settings" : "Налаштування Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Тут ви можете вирішити, яка група матиме доступ до певних розділів налаштувань адміністрування.",
    "None" : "Відсутній",
    "Unable to modify setting" : "Неможливо змінити налаштування",
    "Two-Factor Authentication" : "Двофакторна аутентифікація",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двофакторну автентифікацію можна застосувати для всіх користувачів і окремих груп. Якщо у них не налаштовано двофакторний провайдер, вони не зможуть увійти в систему.",
    "Enforce two-factor authentication" : "Примусова двофакторна аутентифікація",
    "Limit to groups" : "Обмежити групами",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Примусову двофакторну автентифікацію можна встановити лише для певних груп.",
    "Two-factor authentication is enforced for all members of the following groups." : "Двофакторна автентифікація застосовується для всіх учасників наступних груп.",
    "Enforced groups" : "Примусові групи",
    "Two-factor authentication is not enforced for members of the following groups." : "Двофакторна автентифікація не застосовується для учасників наведених нижче груп.",
    "Excluded groups" : "Виключені групи",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Коли групи вибрано/виключено, вони використовують таку логіку, щоб визначити, чи застосовано для користувача 2FA: якщо не вибрано жодної групи, 2FA ввімкнено для всіх, крім членів виключених груп. Якщо вибрано групи, для всіх учасників увімкнено 2FA. Якщо користувач одночасно входить до вибраної та виключеної групи, вибраний має пріоритет і застосовується 2FA.",
    "Save changes" : "Зберегти зміни",
    "All" : "Всі",
    "Limit app usage to groups" : "Обмежити використання застосунку певними групами",
    "No results" : "Немає результатів",
    "Update to {version}" : "Оновити до {version}",
    "Remove" : "Вилучити",
    "Disable" : "Вимкнути",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Цій програмі не призначено мінімальної версії Nextcloud. Це буде помилка в майбутньому.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Для цього застосунку не визначено найвищу версію Nextcloud. Це може викликати помилку в майбутньому.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Цей застосунок не буде встановлено, оскільки такі залежності неможливо виконати:",
    "View in store" : "Переглянути у крамниці застосунків",
    "Visit website" : "Перейти на вебсайт",
    "Report a bug" : "Повідомити про помилку",
    "User documentation" : "Користувацька документація",
    "Admin documentation" : "Документація адміністратора",
    "Developer documentation" : "Документація з розробки",
    "This app is supported via your current Nextcloud subscription." : "Підтримка застосунку через вашу поточну передплату Nextcloud.",
    "Supported" : "Підтримано",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Пропоновані програми розробляються спільнотою та в її рамках. Вони пропонують центральну функціональність і готові до виробничого використання.",
    "Featured" : "Функціональні",
    "Update to {update}" : "Оновити до {update}",
    "All apps are up-to-date." : "Усі застосунки оновлено",
    "Results from other categories" : "Результати з інших категорій",
    "No apps found for your version" : "Відсутні застосунки для вашої версії",
    "Disable all" : "Вимкнути все",
    "Enable all" : "Увімкнути все",
    "_%n app has an update available_::_%n apps have an update available_" : ["Для %n застосунку доступне оновлення","Для %n застосунків доступні оновлення","Для %n застосунків доступні оновлення","Для %n застосунків доступні оновлення"],
    "_Update_::_Update all_" : ["Оновити","Оновити все","Оновити все","Оновити все"],
    "Marked for remote wipe" : "Позначено для віддаленого стирання",
    "Device settings" : "Налаштування пристрою",
    "Allow filesystem access" : "Дозволити доступ до файлової системи",
    "Rename" : "Перейменувати",
    "Revoke" : "Відкликати",
    "Wipe device" : "Стерти дані на пристрої",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Відкликання цього маркера може запобігти видаленню вашого пристрою, якщо він ще не розпочав очищення.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome для Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "Програма для iOS {productName}",
    "{productName} Android app" : "Програма для Android {productName}",
    "{productName} Talk for iOS" : "{productName} Talk для iOS",
    "{productName} Talk for Android" : "{productName} Talk для Android",
    "Sync client - {os}" : "Клієнт синхронізації - {os}",
    "This session" : "Цей сеанс",
    "Device" : "Пристрій",
    "Last activity" : "Остання активність",
    "Devices & sessions" : "Пристрої та сеанси",
    "Web, desktop and mobile clients currently logged in to your account." : "Веб, настільні та мобільні клієнти, які авторизувалися з вашим обліковим записом.",
    "Do you really want to wipe your data from this device?" : "Ви справді хочете стерти дані з цього пристрою?",
    "Confirm wipe" : "Підтвердити стирання даних",
    "Error while creating device token" : "Помилка під час створення токена пристрою",
    "Error while updating device token scope" : "Помилка під час оновлення області маркера пристрою",
    "Error while updating device token name" : "Помилка під час оновлення назви маркера пристрою",
    "Error while deleting the token" : "Помилка при вилученні токену",
    "Error while wiping the device with the token" : "Помилка під час очищення пристрою за допомогою маркера",
    "App name" : "Ім'я застосунку",
    "Create new app password" : "Створіть новий пароль застосунку",
    "Use the credentials below to configure your app or device." : "Використовуйте наведені нижче облікові дані, щоб налаштувати програму або пристрій.",
    "For security reasons this password will only be shown once." : "З міркувань безпеки цей пароль буде показано лише один раз.",
    "Username" : "Ім'я користувача",
    "Password" : "Пароль",
    "Done" : "Готово",
    "Show QR code for mobile apps" : "Показувати QR-код для мобільних застосунків",
    "Copied!" : "Скопійовано!",
    "Copy" : "Копіювати",
    "Could not copy app password. Please copy it manually." : "Не вдалося скопіювати пароль програми. Скопіюйте його вручну.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Для належної роботи сервера важливо правильно налаштувати фонові завдання. Рекомендованим налаштуванням є Cron. Для отримання додаткової інформації перегляньте документацію.",
    "Last job execution ran {time}. Something seems wrong." : "Останнє завдання виконано {раз}. Щось здається не так.",
    "Last job ran {relativeTime}." : "Останнє завдання виконано {relativeTime}.",
    "Background job did not run yet!" : "Фонове завдання ще не виконано!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Виконайте одне завдання з кожною завантаженою сторінкою. Випадок використання: екземпляр для одного користувача.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php зареєстрований у службі webcron для виклику cron.php кожні 5 хвилин через HTTP. Випадок використання: дуже маленький екземпляр (1–5 користувачів залежно від використання).",
    "Cron (Recommended)" : "Cron (рекомендовано)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Для цього вам потрібне розширення PHP POSIX. Додаткову інформацію див. у {linkstart}документації PHP{linkend}.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Використовуйте системну службу cron для виклику файлу cron.php кожні 5 хвилин. Рекомендовано для всіх випадків.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Файл cron.php має бути запущений системним користувачем \"{user}\".",
    "Unable to update background job mode" : "Не вдалося оновити фоновий режим завдання",
    "Profile" : "Профіль",
    "Enable or disable profile by default for new users." : "Увімкнути або вимкнути профіль за замовчуванням для нових користувачів.",
    "Enable" : "Увімкнути",
    "Unable to update profile default setting" : "Не вдалося оновити налаштування профілю за замовчуванням",
    "Server-side encryption" : "Шифрування на сервері",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Шифрування на стороні сервера дозволяє шифрувати файли, завантажені на цей сервер. Це має свою ціну, таку як зниження продуктивності, тому ввімкніть його лише за потреби.",
    "Enable server-side encryption" : "Увімкнути шифрування на сервері",
    "Please read carefully before activating server-side encryption:" : "Уважно прочитайте, перш ніж активувати шифрування на стороні сервера:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Після активації шифрування, всі файли завантажені на сервер з цього моменту, будуть зашифровані на сервері. Відключити шифрування пізніше можна буде тільки якщо активний модуль шифрування підтримує цю функцію, і при виконанні певних умов (наприклад, налаштований ключ відновлення).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Саме по собі шифрування не гарантує безпеку системи. Будь ласка, перегляньте документацію, щоб отримати додаткову інформацію про те, як працює застосунок для шифрування, та про приклади його використання.",
    "Be aware that encryption always increases the file size." : "Майте на увазі, що шифрування завжди збільшує розмір файлів.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Завжди корисно регулярно створювати резервні копії ваших даних, у разі шифрування обов’язково зробіть резервну копію ключів шифрування разом із вашими даними.",
    "This is the final warning: Do you really want to enable encryption?" : "Це останнє попередження: Ви справді хочете ввімкнути шифрування?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Модуль шифрування не завантажено, увімкніть модуль шифрування в меню програми.",
    "Select default encryption module:" : "Обрати модуль шифрування за замовчуванням:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Вам потрібно перенести ключі шифрування зі старого шифрування (ownCloud <= 8.0) на нове. Увімкніть «Модуль шифрування за замовчуванням» і запустіть {command}",
    "Unable to update server side encryption config" : "Не вдалося оновити конфігурацію шифрування на стороні сервера",
    "Rename group" : "Перейменувати групу",
    "Remove group" : "Вилучити групу",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Ви збираєтеся вилучити групу {group}. Зауважте, користувачів групи НЕ буде вилучено.",
    "Please confirm the group removal " : "Будь ласка, підтвердіть вилучення групи",
    "Current password" : "Поточний пароль",
    "New password" : "Новий пароль",
    "Change password" : "Змінити пароль",
    "Your profile picture" : "Ваше зображення профілю",
    "Upload profile picture" : "Завантажте зображення профілю",
    "Choose profile picture from files" : "Виберіть зображення профілю з файлів",
    "Remove profile picture" : "Видалити зображення профілю",
    "png or jpg, max. 20 MB" : "png або jpg, макс. 20 МБ",
    "Picture provided by original account" : "Картинка надана оригінальним обліковим записом",
    "Cancel" : "Скасувати",
    "Set as profile picture" : "Установити як зображення профілю",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Зауважте, що повсюдне оновлення зображення профілю може зайняти до 24 годин.",
    "Choose your profile picture" : "Виберіть зображення профілю",
    "Please select a valid png or jpg file" : "Виберіть дійсний файл png або jpg",
    "Error setting profile picture" : "Помилка налаштування зображення профілю",
    "Error cropping profile picture" : "Помилка кадрування зображення профілю",
    "Error saving profile picture" : "Помилка збереження зображення профілю",
    "Error removing profile picture" : "Помилка видалення зображення профілю",
    "Your biography" : "Ваша біографія",
    "Details" : "Деталі",
    "You are a member of the following groups:" : "Ви є учасником таких груп:",
    "You are using <strong>{usage}</strong>" : "Ви використовуєте <strong>{usage}",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Ви використовуєте <strong>{usage}</strong> із <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Ваше повне ім'я",
    "Email options" : "Параметри електронної пошти",
    "Primary email for password reset and notifications" : "Основна електронна адреса для скидання пароля та сповіщень",
    "Remove primary email" : "Видалити основну електронну адресу",
    "Delete email" : "Видалити електронну пошту",
    "Unset as primary email" : "Скасувати як основну електронну адресу",
    "This address is not confirmed" : "Ця адреса не підтверджена",
    "Set as primary email" : "Установити як основну електронну адресу",
    "Your email address" : "Ваша адреса електронної пошти",
    "Additional email address {index}" : "Додаткова електронна адреса {index}",
    "Unable to delete primary email address" : "Не вдалося видалити основну електронну адресу",
    "Unable to update primary email address" : "Не вдалося оновити основну електронну адресу",
    "Unable to add additional email address" : "Не вдалося додати додаткову електронну адресу",
    "Unable to update additional email address" : "Не вдалося оновити додаткову електронну адресу",
    "Unable to delete additional email address" : "Не вдалося видалити додаткову електронну адресу",
    "No email address set" : "E-mail не вказано",
    "Additional emails" : "Додаткові електронні листи",
    "Your headline" : "Ваш заголовок",
    "Language" : "Мова",
    "Help translate" : "Допомогти з перекладом",
    "Unable to update language" : "Не вдалося оновити мову",
    "No language set" : "Мова не встановлена",
    "Locale" : "Локаль",
    "Week starts on {firstDayOfWeek}" : "Тиждень починається {firstDayOfWeek}",
    "Unable to update locale" : "Не вдалося оновити мову",
    "No locale set" : "Мова не встановлена",
    "Your location" : "Ваше місцезнаходження",
    "Your organisation" : "Ваша організація",
    "Your phone number" : "Ваш номер телефону",
    "Edit your Profile visibility" : "Відредагуйте видимість свого профілю",
    "Enable Profile" : "Увімкнути профіль",
    "Unable to update profile enabled state" : "Неможливо оновити стан профілю",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Для вашого профілю можна встановити певні обмеження з показу інформації про вас. Наприклад, якщо встановлено значення \"Показувати всім\", а для певного значення \"Приватне\", значення \"Приватне\" буде мати вищий пріоритет.",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "Не вдалося оновити видимість {displayId}",
    "Your role" : "Ваша роль",
    "Your Twitter handle" : "Ваш дескриптор Twitter",
    "Your website" : "Твій сайт",
    "No {property} set" : "{property} не встановлено",
    "Unable to update {property}" : "Не вдалося оновити {property}",
    "Change scope level of {property}, current scope is {scope}" : "Змінити рівень дії {property}, поточна область – {scope}",
    "Unable to update federation scope of the primary {property}" : "Не вдалося оновити область федерації основного {property}",
    "Unable to update federation scope of additional {property}" : "Не вдається оновити область федерації додаткового {property}",
    "Add additional email" : "Додайте додаткову електронну адресу",
    "Add" : "Додати",
    "You do not have permissions to see the details of this user" : "Ви не маєте прав для перегляду деталей про цього користувача",
    "Add new password" : "Встановити новий пароль",
    "Add new email address" : "Додати нову адресу електронної пошти",
    "Add user to group" : "Додати користувача до групи",
    "Set user as admin for" : "Встановити користувача як адміністратора для",
    "Select user quota" : "Виберіть квоту користувача",
    "Delete user" : "Вилучити користувача",
    "Wipe all devices" : "Стерти на всіх пристроях",
    "Disable user" : "Вимкнути користувача",
    "Enable user" : "Увімкнути користувача",
    "Resend welcome email" : "Відправити запрошення ще раз",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "У разі втрати пристрою або виходу з організації це може віддалено стерти дані Nextcloud з усіх пристроїв, пов’язаних з {userid}. Працює, лише якщо пристрої підключено до Інтернету.",
    "Remote wipe of devices" : "Віддалене стирання даних на пристрої",
    "Wipe {userid}'s devices" : "Стерти пристрої {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Повністю вилучає обліковий запис {userid} включно з особистими файлами, даними застосунків тощо.",
    "Account deletion" : "Вилучення облікового запису",
    "Delete {userid}'s account" : "Вилучити обліковий запис {userid}",
    "Welcome mail sent!" : "Запрошення надіслано!",
    "Edit User" : "Редагувати користувача",
    "Toggle user actions menu" : "Перемкнути меню дій користувача",
    "{size} used" : "{size} використано",
    "New user" : "Новий користувач",
    "Will be autogenerated" : "Буде створено автоматично",
    "Display name" : "Ім'я для показу",
    "Email" : "E-mail",
    "Default language" : "Мова за замовчуванням",
    "Add a new user" : "Додати нового користувача",
    "Group admin for" : "Адміністратор групи для",
    "Quota" : "Квота",
    "User backend" : "Сервер користувача",
    "Storage location" : "Місце розташування сховища",
    "Last login" : "Останній вхід",
    "No users in here" : "Немає користувачів",
    "Default quota" : "Квота за замовчуванням",
    "Common languages" : "Основні мови",
    "Other languages" : "Інші мови",
    "Password change is disabled because the master key is disabled" : "Зміну пароля вимкнено, оскільки майстер-ключ відключений",
    "Passwordless authentication requires a secure connection." : "Авторизація без пароля вимагає безпечного з'єднання.",
    "Add WebAuthn device" : "Додайте пристрій WebAuthn",
    "Please authorize your WebAuthn device." : "Авторизуйте свій пристрій WebAuthn.",
    "Name your device" : "Дайте назву вашому пристрою",
    "Adding your device …" : "Додавання вашого пристрою...",
    "Server error while trying to add WebAuthn device" : "Помилка сервера під час спроби додати пристрій WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Помилка сервера під час спроби завершити реєстрацію пристрою WebAuthn",
    "Unnamed device" : "Неназваний пристрій",
    "Passwordless Authentication" : "Авторизація без пароля",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Налаштуйте ваш обліковий запис для авторизації без пароля згідно зі стандартами FIDO2.",
    "No devices configured." : "Жодного пристрою не налаштовано.",
    "The following devices are configured for your account:" : "Для вашого облікового запису налаштовано такі пристрої:",
    "Your browser does not support WebAuthn." : "Ваш браузер не підтримує WebAuthn.",
    "Your apps" : "Ваші застосунки",
    "Active apps" : "Активні застосунки",
    "Disabled apps" : "Неактивні застосунки",
    "Updates" : "Оновлення",
    "App bundles" : "Набори застосунків",
    "Featured apps" : "Функціональні застосунки",
    "{license}-licensed" : "Ліцензія: {license}",
    "Changelog" : "Зміни",
    "by {author}\n{license}" : "автор: {author} {ліцензія}",
    "Enter group name" : "Зазначте назву групи",
    "Add group" : "Додати групу",
    "Active users" : "Активні користувачі",
    "Admins" : "Адміністратори",
    "Disabled users" : "Вимкнені користувачі",
    "Default quota:" : "Квота за замовчуванням:",
    "Select default quota" : "Виберіть квоту за замовчуванням",
    "Show Languages" : "Показати мови",
    "Show last login" : "Показати останній вхід",
    "Show user backend" : "Показати користувача",
    "Show storage path" : "Показати шлях до сховища",
    "Send email to new user" : "Надіслати email новому користувачу",
    "Not saved" : "Не збережено",
    "Sending…" : "Відправка...",
    "Email sent" : "Лист надіслано",
    "Location" : "Місце",
    "Profile picture" : "Зображення облікового запису",
    "About" : "Про систему",
    "Full name" : "Повне ім'я",
    "Additional email" : "Додаткова електронна адреса",
    "Headline" : "Заголовок",
    "Organisation" : "Організація",
    "Phone number" : "Номер телефону",
    "Role" : "Роль",
    "Twitter" : "Twitter",
    "Website" : "Вебсайт",
    "Profile visibility" : "Видимість профілю",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Недоступно, оскільки ця властивість необхідна для основних функцій, включаючи спільний доступ до файлів і запрошення в календарі",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Недоступно, оскільки публікація даних користувача на пошуковому сервері заборонена. Зверніться до системного адміністратора, якщо у вас виникнуть запитання",
    "Show to everyone" : "Показувати всім",
    "Show to logged in users only" : "Показувати лише авторизованим користувачам",
    "Hide" : "Сховати",
    "Download and enable" : "Завантажити та увімкнути",
    "Enable untested app" : "Увімкнути непротестований застосунок",
    "The app will be downloaded from the App Store" : "Застосунок буде завантажено з App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Відсутня інформація щодо підтримки цього застосунку вашою версією Nextcloud. Ви зможете встановити цей застосунок, проте він може працювати не так, як ви очікуєте.",
    "Never" : "Ніколи",
    "An error occurred during the request. Unable to proceed." : "Під час запиту сталася помилка. Неможливо продовжити.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Застосунок активовано, але його потрібно оновити. Вас буде переспрямовано на сторінку оновлення через 5 секунд.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Помилка: цю програму неможливо ввімкнути, оскільки вона робить сервер нестабільним",
    "Administrator documentation" : "Документація адміністратора",
    "Documentation" : "Документація",
    "Forum" : "Форум",
    "Login" : "Логін",
    "Plain" : "Звичайний",
    "NT LAN Manager" : "Менеджер NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Відкрити документацію",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Важливо налаштувати цей сервер, для надсилання електронних листів, наприклад, для скидання пароля та сповіщень.",
    "Send mode" : "Режим надсилання",
    "Encryption" : "Шифрування",
    "Sendmail mode" : "Режим Sendmail",
    "From address" : "Адреса відправника",
    "Authentication method" : "Спосіб аутентифікації",
    "Authentication required" : "Потрібна аутентифікація",
    "Server address" : "Адреса сервера",
    "Port" : "Порт",
    "Credentials" : "Облікові дані",
    "SMTP Username" : "Ім'я користувача SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Save" : "Зберегти",
    "Test and verify email settings" : "Перевірте та перевірте налаштування електронної пошти",
    "Send email" : "Надіслати листа",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Для безпеки та продуктивності вашого сервера важливо, щоб все було налаштовано правильно. Щоб допомогти вам, ми робимо деякі автоматичні перевірки. Будь ласка, перегляньте пов'язану документацію для отримання додаткової інформації.",
    "All checks passed." : "Всі перевірки виконано.",
    "There are some errors regarding your setup." : "У ваших налаштуваннях є деякі помилки.",
    "There are some warnings regarding your setup." : "У ваших налаштуваннях є деякі застереження.",
    "Checking for system and security issues." : "Перевірка проблем системи та безпеки.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Ще раз перевірте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">посібники зі встановлення ↗</a> та перевірте, чи немає помилок чи попереджень у <a href=\"%2$s\">журналі</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Перевірте безпеку вашого Nextcloud <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">скануванням безпеки ↗</a>.",
    "Version" : "Версія",
    "You need to enable the File sharing App." : "Потрібно увімкнути застосунок для обміну файлами.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Як адміністратор ви можете точно налаштувати поведінку спільного використання. Будь ласка, перегляньте документацію для отримання додаткової інформації.",
    "Allow apps to use the Share API" : "Дозволити застосункам використовувати API спільного доступу",
    "Set default expiration date for shares" : "Установіть термін дії акцій за умовчанням",
    "Expire after" : "Термін дії закінчується після",
    "day(s)" : "день (дні)",
    "Enforce expiration date" : "Термін дії обов'язковий",
    "Set default expiration date for shares to other servers" : "Установіть термін дії за замовчуванням для спільних ресурсів для інших серверів",
    "Allow users to share via link and emails" : "Дозволити користувачам ділитися за допомогою посилань і електронних листів",
    "Allow public uploads" : "Дозволити публічне завантаження",
    "Always ask for a password" : "Завжди запитувати пароль",
    "Enforce password protection" : "Захист паролем обов'язковий",
    "Exclude groups from password requirements:" : "Виключити групи з вимог щодо пароля:",
    "Set default expiration date" : "Встановити термін дії за замовчуванням",
    "Exclude groups from creating link shares:" : "Виключити групи зі створення спільних посилань:",
    "Allow resharing" : "Дозволити перевідкривати спільний доступ",
    "Allow sharing with groups" : "Дозволити спільне використання групами",
    "Restrict users to only share with users in their groups" : "Дозволити користувачам відкривати спільний доступ лише для користувачів з їхньої групи",
    "Exclude groups from sharing" : "Виключити групи зі спільного доступу",
    "These groups will still be able to receive shares, but not to initiate them." : "Ці групи зможуть отримувати спільні файли, але не зможуть відправляти їх.",
    "Allow username autocompletion in share dialog" : "Дозволити автозаповнення імені користувача в діалоговому вікні спільного доступу",
    "Allow username autocompletion to users within the same groups" : "Дозволити автозавершення імен користувачів для користувачів у тих самих групах",
    "Allow username autocompletion to users based on phone number integration" : "Дозволити користувачам автозаповнення імені користувача на основі інтеграції номера телефону",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Якщо ввімкнуто автозавершення «та сама група» та «інтеграція номеру телефону», збігу в будь-якому з них достатньо, щоб показати користувачеві.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Дозволити автозавершення під час введення повного імені або адреси електронної пошти (ігнорування відсутніх збігів телефонної книги та перебування в одній групі)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Показувати текст застереження на сторінці завантаження загальнодоступного посилання (відображається, лише якщо список файлів приховано)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Цей текст буде показано на сторінці завантаження загальнодоступного посилання, коли список файлів приховано.",
    "Default share permissions" : "Дозволи на публікування по замовчуванню",
    "Reasons to use Nextcloud in your organization" : "Причини використовувати Nextcloud у вашій організації",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Розроблено {communityopen}спільнотою Nextcloud{linkclose}. Ліцензія {licenseopen}AGPL{linkclose} на {githubopen}початковий код{linkclose}.",
    "Like our Facebook page" : "Вподобайте нашу сторінку у Facebook",
    "Follow us on Twitter" : "Слідкуйте за нами в Twitter",
    "Follow us on Mastodon" : "Слідкуйте за нами на Mastodon",
    "Check out our blog" : "Перегляньте наш блог",
    "Subscribe to our newsletter" : "Підпишіться на нашу розсилку",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Цей випуск спільноти Nextcloud не підтримується, і миттєві сповіщення недоступні.",
    "Use a second factor besides your password to increase security for your account." : "Використовуйте другий фактор, крім пароля, щоб підвищити безпеку свого облікового запису.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Якщо ви використовуєте програми сторонніх розробників для підключення до Nextcloud, переконайтеся, що ви створили та налаштували пароль програми для кожної з них, перш ніж увімкнути автентифікацію за другим фактором.",
    "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
    "Migration started …" : "Міграцію розпочато ...",
    "An error occurred while changing your language. Please reload the page and try again." : "Виникла помилка при зміні мови. Перезавантажте сторінку та повторіть спробу.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Виникла помилка при зміні локалі. Перезавантажте сторінку та спробуйте ще раз.",
    "Select a profile picture" : "Обрати зображення облікового запису",
    "Week starts on {fdow}" : "Перший день тижня: {fdow}",
    "Couldn't remove app." : "Неможливо вилучити застосунок.",
    "Couldn't update app." : "Не вдалося оновити застосунок.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Бекенд не підтримує зміну пароля, але ключ шифрування користувача був оновлений.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Не вдалося визначити, чи TLS-версія cURL застаріла, оскільки сталася помилка під час запиту HTTPS до https://nextcloud.com. Будь ласка, перевірте файл журналу nextcloud для отримання додаткової інформації.",
    "You need to set your user email before being able to send test emails." : "Перед надсиланням тестових листів ви повинні вказати свою email адресу.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Відкликання цього токена може запобігти стиранню даних на вашому пристрої, якщо процес стирання ще не було розпочато.",
    "Set as primary mail" : "Встановити як основну пошту",
    "Change privacy level of email" : "Змінити рівень конфіденційності електронної пошти",
    "All languages" : "Всі мови",
    "Everyone" : "Всі",
    "An error occured during the request. Unable to proceed." : "Під час запиту сталася помилка. Не вдається продовжити.",
    "Test email settings" : "Тестувати налаштування ел. пошти",
    "Please read carefully before activating server-side encryption: " : "Будьте обережні під час активування шифрування на сервері:",
    "Enable encryption" : "Увімкнути шифрування",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Вам потрібно перенести ключі шифрування зі старого шифрування (ownCloud <= 8.0) на нове. Увімкніть «Модуль шифрування за замовчуванням» і запустіть «occ encryption:migrate»",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Вам потрібно перенести ключі шифрування зі старого шифрування (ownCloud <= 8.0) на нове.",
    "Start migration" : "Розпочати міграцію",
    "Last job execution ran %s. Something seems wrong." : "Виконано останнє завдання %s. Щось здається не так.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Деякі завдання не виконувалися з %s. Розгляньте можливість збільшення частоти виконання.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Деякі завдання не виконано з %s. Розгляньте можливість переходу на системний cron.",
    "Last job ran %s." : "Останнє завдання запускалось %s.",
    "Background job didn’t run yet!" : "Фонове завдання ще не виконано!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Для належної роботи сервера важливо правильно налаштувати фонові завдання. Рекомендованим параметром є \"Cron\". Для отримання додаткової інформації перегляньте документацію.",
    "Pick background job setting" : "Виберіть налаштування фонової роботи",
    "Recommended" : "Рекомендуємо",
    "The cron.php needs to be executed by the system user \"%s\"." : "Файл cron.php має бути запущений системним користувачем \"%s\".",
    "days" : "днів",
    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Дозволити автозаповнення імені користувача під час введення повного імені або адреси електронної пошти (ігнорування відсутніх збігів телефонної книги та перебування в одній групі)",
    "Change privacy level of profile picture" : "Змінити рівень конфіденційності зображення профілю",
    "Upload new" : "Завантажити нове",
    "Select from Files" : "Вибрати з файлів",
    "Remove image" : "Вилучити зображення",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Будь ласка, зверніть увагу, що для повного оновлення аватара може знадобитися до 24 годин.",
    "Choose as profile picture" : "Вибрати зображенням профілю",
    "You are using <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Ви використовуєте <strong>%1$s</strong> з <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of full name" : "Змінити рівень конфіденційності повного імені",
    "No display name set" : "Ім'я для показу не встановлено",
    "Change privacy level of phone number" : "Змінити рівень конфіденційності номера телефону",
    "Address" : "Адреса",
    "Change privacy level of address" : "Змінити рівень конфіденційності адреси",
    "Your postal address" : "Ваша поштова адреса",
    "Change privacy level of website" : "Змінити рівень конфіденційності веб-сайту",
    "It can take up to 24 hours before the account is displayed as verified." : "Підтвердження облікового запису може тривати до 24 годин.",
    "Link https://…" : "Посилання https://…",
    "Change privacy level of Twitter profile" : "Змінити рівень конфіденційності профілю Twitter",
    "Twitter handle @…" : "Ім'я в Twitter @…",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Майже перевищено максимальну кількість ключів OPcache. Щоб переконатися, що всі сценарії можна зберігати в кеші, рекомендується застосувати <code>opcache.max_accelerated_files</code> до вашої конфігурації PHP зі значенням, вищим за <code>%s</code>.",
    "Admin privileges" : "Права адміністратора",
    "Unable to update biography" : "Не вдалося оновити біографію",
    "Unable to update full name" : "Не вдалося оновити повне ім'я",
    "No full name set" : "Немає повного імені",
    "Unable to update headline" : "Не вдалося оновити заголовок",
    "Unable to update organisation" : "Не вдалося оновити організацію",
    "Unable to update role" : "Не вдалося оновити роль",
    "Change scope level of {accountProperty}" : "Змінити рівень дії {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "Не вдалося оновити область федерації основного {accountProperty}",
    "Unable to update federation scope of additional {accountProperty}" : "Не вдалося оновити область федерації додаткового {accountProperty}",
    "Avatar" : "Світлина"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
